# sdtg-lib
Second-dimensional Telegram Games library.
## Requires:
`pyTelegramBotApi`
## Installing by requirements.txt:
`git+git://github.com/Vezono2/sdtg-lib#egg=sdtg`

## Usage:
See examples for all details.

